@@ -14,7 +14,8 @@ from .handlers import (
     BrokerResponseException,
 )
 from .messages import (
-    REPLY_TOPIC_CONTEXT_VAR,
+    REQUEST_HEADERS_CONTEXT_VAR,
+    REQUEST_REPLY_TOPIC_CONTEXT_VAR,
     BrokerMessage,
     BrokerMessageStatus,
     BrokerMessageStrategy,
