@@ -14,6 +14,8 @@ from .definitions import (
     BrokerQueryEnrouteDecorator,
     EnrouteDecorator,
     EnrouteDecoratorKind,
+    PeriodicEnrouteDecorator,
+    PeriodicEventEnrouteDecorator,
     RestCommandEnrouteDecorator,
     RestEnrouteDecorator,
     RestQueryEnrouteDecorator,
